# Movable Type plugin.
#
# Release 0.01 (Jan 17, 2008) initial version.
# Release 0.02 (Jan 22, 2008) correspond option window.
# Release 0.03 (Feb 17, 2008) fixed bug.
#
# Copyright (c) 2004-2008 Yujiro Araki

package MT::Plugin::VisibleCustomFieldImage;
use strict;
use MT;
use base qw(MT::Plugin);

our $VERSION = '0.03';

my $plugin = MT::Plugin::VisibleCustomFieldImage->new({
    name => 'VisibleCustomFieldImage',
    description => 'Set default value for entry.',
    doc_link => 'http://www.koikikukan.com/archives/2007/01/23-003733.php',
    author_name => 'Yujiro Araki',
    author_link => 'http://www.koikikukan.com/',
    version => $VERSION,
});
MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        callbacks => {
            'MT::App::CMS::template_source.asset-chooser'
                => \&visible_custom_field_image,
        },
   });
}

sub visible_custom_field_image {
    my ($cb, $app, $template) = @_;

    my $old = <<HERE;
function insertCustomFieldAsset(html, id) {
HERE
    $old = quotemeta($old);
    my $new = <<HERE;
function displayCustomFieldAsset(field_id,href) {
  var elm = document.getElementById(field_id + '_preview');
  var img = elm.getElementsByTagName('img')[0];
  var def_width = 200;
  if(img.width > 0) {
    if(img.width > def_width) {
      var pct = def_width / img.width;
      img.height = Math.floor(pct * img.height); // 'img.width' must be after.
      img.width = def_width;
      getByID(field_id + '_preview').innerHTML = 
        '<a href="' + href + '" class="highslide" onclick="return hs.expand(this)"><img src="' + href + '" width="' + img.width + '" height="' + img.height + '" class="custom_field_image" /></a>';
    }
//  img.style.display = 'block';
  }
}
function insertCustomFieldAsset(html, id) {
HERE
    $$template =~ s/$old/$new/;

    $old = <<HERE;
getByID(id + '_preview').innerHTML = form.innerHTML;
HERE
    $old = quotemeta($old);
    $new = <<HERE;
var field_id = id;
var anchor = form.getElementsByTagName("a")[0];
var href;
if (!anchor) {
  var img = form.getElementsByTagName("img")[0];
  href = img.getAttribute("src");
} else {
  href = anchor.getAttribute("href");
}

if (href.match(/\\.jpg|\\.gif|\\.png/)) {
  if (!anchor) {
    form.innerHTML = '<a href="' + href + '"><img src="' + href + '" onload="displayCustomFieldAsset(\\''+id+'\\',\\''+href+'\\')" /></a>';
  } else {
    anchor.innerHTML = '<img src="' + href + '" onload="displayCustomFieldAsset(\\''+id+'\\',\\''+href+'\\')" />';
    var img = anchor.getElementsByTagName('img')[0];
//  img.style.display = 'none';
  }
}
getByID(id + '_preview').innerHTML = form.innerHTML;
HERE
    $$template =~ s/$old/$new/;

    $old = <<HERE;
<div id="<mt:var name="field_id">_preview" class="customfield_preview">
	<mt:var name="value">
</div>
HERE
    $old = quotemeta($old);
    $new = <<HERE;
<div id="<mt:var name="field_id">_preview" class="customfield_preview">
	<mt:var name="value">
</div>
<script type="text/javascript">
function insertCustomFieldAssetAfterSave() {
  try {
    var elm = getByID('<mt:var name="field_id">_preview');
    var anchor = elm.getElementsByTagName("a")[0];
    var href;
    if (!anchor) {
      var img = elm.getElementsByTagName("img")[0];
      href = img.getAttribute("src");
    } else {
      href = anchor.getAttribute("href");
    }
    if (href.match(/\\.jpg|\\.gif|\\.png/)) {
      if (!anchor) {
        elm.innerHTML = '<a href="' + href + '"><img src="' + href + '" onload="displayCustomFieldAsset(\\'<mt:var name="field_id">\\',\\'' + href + '\\')" /></a>';
      } else {
        anchor.innerHTML = '<img src="' + href + '" onload="displayCustomFieldAsset(\\'<mt:var name="field_id">\\',\\'' + href + '\\')" />';
        var img = anchor.getElementsByTagName('img')[0];
      }
    }
  } catch(e) { 
    log.error(e);
  };
}
insertCustomFieldAssetAfterSave();
</script>
HERE
    $$template =~ s/$old/$new/;

    $old = <<HERE;
onclick="return openDialog(this.form, 'list_assets', '_type=asset&amp;blog_id=<mt:var name="blog_id">&amp;dialog_view=1&amp;filter=class&amp;filter_val=<mt:var name="asset_type">&amp;<mt:if name="asset_type" ne="asset">require_type=<mt:var name="asset_type">&amp;</mt:if>edit_field=<mt:var name="field_id">&amp;asset_select=1')"
HERE
    $old = quotemeta($old);
    $new = <<HERE;
onclick="return openDialog(this.form, 'list_assets', '_type=asset&amp;blog_id=<mt:var name="blog_id">&amp;dialog_view=1&amp;filter=class&amp;filter_val=<mt:var name="asset_type">&amp;<mt:if name="asset_type" ne="asset">require_type=<mt:var name="asset_type">&amp;</mt:if>edit_field=<mt:var name="field_id">&amp;asset_select=0')"
HERE
    $$template =~ s/$old/$new/;

}

1;
